@@ -1,11 +1,12 @@
 FinTS.stats <- function(x){
-  {
-    if(require('zoo'))
+#  {
+#   Don't need as zoo is in depends
+#    if(require('zoo'))
       Start <- min(index(x))
-    else
-      warning('requires(zoo) for Start; ',
-              ' returning 1')
-  }
+#    else
+#      warning('requires(zoo) for Start; ',
+#              ' returning 1')
+#  }
   N <- sum(!is.na(x))
   Mean <- mean(x, na.rm=TRUE)
   Sd <- sd(x, na.rm=TRUE)
@@ -23,7 +24,7 @@ FinTS.stats <- function(x){
   }
   Min <- min(x, na.rm=TRUE)
   Max <- max(x,na.rm=TRUE)
-#  
+#
   data.frame(Start=Start, Size=N, Mean=Mean, Standard.Deviation=Sd,
     Skewness=sk, Excess.Kurtosis=kurt, Minimum=Min,
     Maximum=Max)
